@@ -61,10 +61,28 @@ def index_helper(path: str):
         return
 
     indexed_repos = code_finder.list_indexed_repositories()
-    if any(Path(repo["path"]).resolve() == path_obj for repo in indexed_repos):
-        console.print(f"[yellow]Repository '{path}' is already indexed. Skipping.[/yellow]")
-        db_manager.close_driver()
-        return
+    repo_exists = any(Path(repo["path"]).resolve() == path_obj for repo in indexed_repos)
+    
+    if repo_exists:
+        # Check if the repository actually has files (not just an empty node from interrupted indexing)
+        try:
+            with db_manager.get_driver().session() as session:
+                result = session.run(
+                    "MATCH (r:Repository {path: $path})-[:CONTAINS]->(f:File) RETURN count(f) as file_count",
+                    path=str(path_obj)
+                )
+                record = result.single()
+                file_count = record["file_count"] if record else 0
+                
+                if file_count > 0:
+                    console.print(f"[yellow]Repository '{path}' is already indexed with {file_count} files. Skipping.[/yellow]")
+                    console.print("[dim]💡 Tip: Use 'cgc index --force' to re-index[/dim]")
+                    db_manager.close_driver()
+                    return
+                else:
+                    console.print(f"[yellow]Repository '{path}' exists but has no files (likely interrupted). Re-indexing...[/yellow]")
+        except Exception as e:
+            console.print(f"[yellow]Warning: Could not check file count: {e}. Proceeding with indexing...[/yellow]")
 
     console.print(f"Starting indexing for: {path_obj}")
     console.print("[yellow]This may take a few minutes for large repositories...[/yellow]")
@@ -77,6 +95,19 @@ def index_helper(path: str):
         time_end = time.time()
         elapsed = time_end - time_start
         console.print(f"[green]Successfully finished indexing: {path} in {elapsed:.2f} seconds[/green]")
+        
+        # Check if auto-watch is enabled
+        try:
+            from codegraphcontext.cli.config_manager import get_config_value
+            auto_watch = get_config_value('ENABLE_AUTO_WATCH')
+            if auto_watch and str(auto_watch).lower() == 'true':
+                console.print("\n[cyan]🔍 ENABLE_AUTO_WATCH is enabled. Starting watcher...[/cyan]")
+                db_manager.close_driver()  # Close before starting watcher
+                watch_helper(path)  # This will block the terminal
+                return  # watch_helper handles its own cleanup
+        except Exception as e:
+            console.print(f"[yellow]Warning: Could not check ENABLE_AUTO_WATCH: {e}[/yellow]")
+            
     except Exception as e:
         console.print(f"[bold red]An error occurred during indexing:[/bold red] {e}")
     finally:
@@ -392,9 +423,13 @@ def clean_helper():
     try:
         with db_manager.get_driver().session() as session:
             # Find and delete orphaned nodes (nodes not connected to any repository)
+            # Using OPTIONAL MATCH for FalkorDB compatibility
             query = """
             MATCH (n)
-            WHERE NOT (n:Repository) AND NOT EXISTS((n)-[]-(:Repository))
+            WHERE NOT (n:Repository)
+            OPTIONAL MATCH path = (n)-[*]-(r:Repository)
+            WITH n, path
+            WHERE path IS NULL
             WITH n LIMIT 1000
             DETACH DELETE n
             RETURN count(n) as deleted
@@ -519,8 +554,14 @@ def stats_helper(path: str = None):
 
 def watch_helper(path: str):
     """Watch a directory for changes and auto-update the graph (blocking mode)."""
+    import logging
     from ..core.watcher import CodeWatcher
     
+    # Suppress verbose watchdog DEBUG logs
+    logging.getLogger('watchdog').setLevel(logging.WARNING)
+    logging.getLogger('watchdog.observers').setLevel(logging.WARNING)
+    logging.getLogger('watchdog.observers.inotify_buffer').setLevel(logging.WARNING)
+    
     services = _initialize_services()
     if not all(services):
         return
