@@ -9,9 +9,16 @@ import json
 import sys
 import shutil
 import yaml 
+from codegraphcontext.core.database import DatabaseManager
 
 console = Console()
 
+# Constants for Docker Neo4j setup
+DEFAULT_NEO4J_URI = "neo4j://localhost:7687"
+DEFAULT_NEO4J_USERNAME = "neo4j"
+DEFAULT_NEO4J_BOLT_PORT = 7687
+DEFAULT_NEO4J_HTTP_PORT = 7474
+
 def _generate_mcp_json(creds):
     """Generates and prints the MCP JSON configuration."""
     cgc_path = shutil.which("cgc") or sys.executable
@@ -19,10 +26,10 @@ def _generate_mcp_json(creds):
     if "python" in Path(cgc_path).name:
         # fallback to running as module if no cgc binary is found
         command = cgc_path
-        args = ["-m", "cgc", "start"]
+        args = ["-m", "cgc", "mcp", "start"]
     else:
         command = cgc_path
-        args = ["start"]
+        args = ["mcp","start"]
 
     mcp_config = {
         "mcpServers": {
@@ -36,12 +43,13 @@ def _generate_mcp_json(creds):
                 },
                 "tools": {
                     "alwaysAllow": [
-                        "list_imports", "add_code_to_graph", "add_package_to_graph",
+                        "add_code_to_graph", "add_package_to_graph",
                         "check_job_status", "list_jobs", "find_code",
                         "analyze_code_relationships", "watch_directory",
                         "find_dead_code", "execute_cypher_query",
                         "calculate_cyclomatic_complexity", "find_most_complex_functions",
-                        "list_indexed_repositories", "delete_repository"
+                        "list_indexed_repositories", "delete_repository", "list_watched_paths", 
+                        "unwatch_directory", "visualize_graph_query"
                     ],
                     "disabled": False
                 },
@@ -72,6 +80,25 @@ def _generate_mcp_json(creds):
     console.print(f"[cyan]Neo4j credentials also saved to: {env_file}[/cyan]")
     _configure_ide(mcp_config)
 
+
+def find_jetbrains_mcp_config():
+    bases = [
+        Path.home() / ".config" / "JetBrains",
+        Path.home() / "Library/Application Support/JetBrains",
+        Path.home() / "AppData/Roaming/JetBrains"
+    ]
+    configs = []
+    for base in bases:
+        if base.exists():
+            for folder in base.iterdir():  # each IDE/version
+                options = folder / "options"
+                mcp_file = options / "mcpServer.xml"
+                if mcp_file.exists():
+                    configs.append(mcp_file)
+                    print(mcp_file)
+                    return configs
+
+
 def convert_mcp_json_to_yaml():
     json_path = Path.cwd() / "mcp.json"
     yaml_path = Path.cwd() / "devfile.yaml"
@@ -87,7 +114,7 @@ def _configure_ide(mcp_config):
     questions = [
         {
             "type": "confirm",
-            "message": "Automatically configure your IDE/CLI (VS Code, Cursor, Windsurf, Claude, Gemini, Cline, RooCode, ChatGPT Codex, Amazon Q Developer)?",
+            "message": "Automatically configure your IDE/CLI (VS Code, Cursor, Windsurf, Claude, Gemini, Cline, RooCode, ChatGPT Codex, Amazon Q Developer, Aider)?",
             "name": "configure_ide",
             "default": True,
         }
@@ -101,7 +128,7 @@ def _configure_ide(mcp_config):
         {
             "type": "list",
             "message": "Choose your IDE/CLI to configure:",
-            "choices": ["VS Code", "Cursor", "Windsurf", "Claude code", "Gemini CLI", "ChatGPT Codex", "Cline", "RooCode", "Amazon Q Developer", "None of the above"],
+            "choices": ["VS Code", "Cursor", "Windsurf", "Claude code", "Gemini CLI", "ChatGPT Codex", "Cline", "RooCode", "Amazon Q Developer", "JetBrainsAI", "Aider", "None of the above"],
             "name": "ide_choice",
         }
     ]
@@ -112,7 +139,8 @@ def _configure_ide(mcp_config):
         console.print("\n[cyan]You can add the MCP server manually to your IDE/CLI.[/cyan]")
         return
 
-    if ide_choice in ["VS Code", "Cursor", "Claude code", "Gemini CLI", "ChatGPT Codex", "Cline", "Windsurf", "RooCode", "Amazon Q Developer"]:
+
+    if ide_choice in ["VS Code", "Cursor/CLI", "Claude code", "Gemini CLI", "ChatGPT Codex", "Cline", "Windsurf", "RooCode", "Amazon Q Developer , JetBrainsAI", "Aider"]:
         console.print(f"\n[bold cyan]Configuring for {ide_choice}...[/bold cyan]")
 
         if ide_choice == "Amazon Q Developer":
@@ -125,7 +153,7 @@ def _configure_ide(mcp_config):
                 Path.home() / "Library" / "Application Support" / "Code" / "User" / "settings.json",
                 Path.home() / "AppData" / "Roaming" / "Code" / "User" / "settings.json"
             ],
-            "Cursor": [
+            "Cursor/CLI": [
                 Path.home() / ".cursor" / "settings.json",
                 Path.home() / ".config" / "cursor" / "settings.json",
                 Path.home() / "Library" / "Application Support" / "cursor" / "settings.json",
@@ -156,10 +184,20 @@ def _configure_ide(mcp_config):
                 Path.home() / "Library" / "Application Support" / "Code" / "User" / "globalStorage" / "saoudrizwan.claude-dev" / "settings" / "cline_mcp_settings.json",
                 Path.home() / "AppData" / "Roaming" / "Code" / "User" / "globalStorage" / "saoudrizwan.claude-dev" / "settings" / "cline_mcp_settings.json"
             ],
+
+            "JetBrainsAI": find_jetbrains_mcp_config(), #only for jetbrains ide
+
             "RooCode": [
                 Path.home() / ".config" / "Code" / "User" / "settings.json",   # Linux 
                 Path.home() / "AppData" / "Roaming" / "Code" / "User" / "settings.json",  # Windows
                 Path.home() / "Library" / "Application Support" / "Code" / "User" / "settings.json"  # macOS
+            ],
+            "Aider": [
+                Path.home() / ".aider" / "settings.json",
+                Path.home() / ".config" / "aider" / "settings.json",
+                Path.home() / "Library" / "Application Support" / "aider" / "settings.json",
+                Path.home() / "AppData" / "Roaming" / "aider" / "settings.json",
+                Path.home() / ".config" / "Aider" / "User" / "settings.json",
             ]
         }
 
@@ -245,17 +283,18 @@ def run_command(command, console, shell=False, check=True, input_text=None):
         console.print(f"[bold red]Command timed out:[/bold red] {cmd_str}")
         return None
 
-def run_setup_wizard():
-    """Guides the user through setting up CodeGraphContext."""
-    console.print("[bold cyan]Welcome to the CodeGraphContext Setup Wizard![/bold cyan]")
+def run_neo4j_setup_wizard():
+    """Guides the user through setting up Neo4j database for CodeGraphContext."""
+    console.print("[bold cyan]Welcome to the Neo4j Setup Wizard![/bold cyan]")
     
     questions = [
         {
             "type": "list",
-            "message": "Where is your Neo4j database located? We can help you get one, if you don't have.",
+            "message": "Where do you want to setup your Neo4j database?",
             "choices": [
                 "Local (Recommended: I'll help you run it on this machine)",
                 "Hosted (Connect to a remote database like AuraDB)",
+                "I already have an existing neo4j instance running.",
             ],
             "name": "db_location",
         }
@@ -265,8 +304,114 @@ def run_setup_wizard():
 
     if db_location and "Hosted" in db_location:
         setup_hosted_db()
-    elif db_location:
+    elif db_location and "Local" in db_location:
         setup_local_db()
+    elif db_location:
+        setup_existing_db()
+
+
+def configure_mcp_client():
+    """
+    Configure MCP client (IDE/CLI) integration.
+    This function sets up the MCP server configuration for the user's IDE.
+    Includes all current configuration values in the env section.
+    """
+    console.print("[bold cyan]MCP Client Configuration[/bold cyan]\n")
+    console.print("This will configure CodeGraphContext integration with your IDE or CLI tool.")
+    console.print("CodeGraphContext works with FalkorDB by default (no database setup needed).\n")
+    
+    # Load current configuration (includes project-local .env if present)
+    try:
+        from codegraphcontext.cli.config_manager import load_config
+        config = load_config()
+    except Exception as e:
+        console.print(f"[yellow]Warning: Could not load configuration: {e}[/yellow]")
+        config = {}
+    
+    # Build env section with all configuration values
+    env_vars = {}
+    
+    # Add database credentials if they exist
+    env_file = Path.home() / ".codegraphcontext" / ".env"
+    if env_file.exists():
+        try:
+            with open(env_file, "r") as f:
+                for line in f:
+                    line = line.strip()
+                    if line and not line.startswith("#") and "=" in line:
+                        key, value = line.split("=", 1)
+                        key = key.strip()
+                        if key in ["NEO4J_URI", "NEO4J_USERNAME", "NEO4J_PASSWORD"]:
+                            env_vars[key] = value.strip()
+        except Exception:
+            pass
+    
+    # Add all configuration values, converting relative paths to absolute
+    for key, value in config.items():
+        # Skip database credentials (already added above)
+        if key in ["NEO4J_URI", "NEO4J_USERNAME", "NEO4J_PASSWORD"]:
+            continue
+        
+        # Convert relative paths to absolute for path-related configs
+        if "PATH" in key and value:
+            path_obj = Path(value)
+            if not path_obj.is_absolute():
+                value = str(path_obj.resolve())
+        
+        env_vars[key] = value
+    
+    # Generate MCP configuration
+    cgc_path = shutil.which("cgc") or sys.executable
+
+    if "python" in Path(cgc_path).name:
+        # fallback to running as module if no cgc binary is found
+        command = cgc_path
+        args = ["-m", "cgc", "mcp", "start"]
+    else:
+        command = cgc_path
+        args = ["mcp", "start"]
+
+    # Create MCP config with complete env section
+    mcp_config = {
+        "mcpServers": {
+            "CodeGraphContext": {
+                "command": command,
+                "args": args,
+                "env": env_vars,
+                "tools": {
+                    "alwaysAllow": [
+                        "add_code_to_graph", "add_package_to_graph",
+                        "check_job_status", "list_jobs", "find_code",
+                        "analyze_code_relationships", "watch_directory",
+                        "find_dead_code", "execute_cypher_query",
+                        "calculate_cyclomatic_complexity", "find_most_complex_functions",
+                        "list_indexed_repositories", "delete_repository", "list_watched_paths", 
+                        "unwatch_directory", "visualize_graph_query"
+                    ],
+                    "disabled": False
+                },
+                "disabled": False,
+                "alwaysAllow": []
+            }
+        }
+    }
+
+    console.print("\n[bold green]Configuration generated![/bold green]")
+    console.print("Copy the following JSON and add it to your MCP server configuration file:")
+    console.print(json.dumps(mcp_config, indent=2))
+
+    # Save to file for convenience
+    mcp_file = Path.cwd() / "mcp.json"
+    with open(mcp_file, "w") as f:
+        json.dump(mcp_config, f, indent=2)
+    console.print(f"\n[cyan]Configuration saved to: {mcp_file}[/cyan]")
+    
+    # Configure IDE automatically
+    _configure_ide(mcp_config)
+    
+    console.print("\n[bold green]✅ MCP Client configuration complete![/bold green]")
+    console.print("[cyan]You can now run 'cgc mcp start' to launch the server.[/cyan]")
+    console.print("[yellow]💡 Tip: To update MCP config after changing settings, re-run 'cgc mcp setup'[/yellow]\n")
 
 
 def find_latest_neo4j_creds_file():
@@ -283,6 +428,122 @@ def find_latest_neo4j_creds_file():
     return latest_file
 
 
+def setup_existing_db():
+    """Guides user to configure an existing Neo4j instance."""
+    console.print("\nTo connect to an existing Neo4j database, you'll need your connection credentials.")
+    console.print("If you don't have credentials for the database, you can create a new one using 'Local' installation in the previous menu.")
+    
+    questions = [
+
+        {
+            "type": "list",
+            "message": "How would you like to add your Neo4j credentials?",
+            "choices": ["Add credentials from file", "Add credentials manually"],
+            "name": "cred_method",
+        }
+    ]
+    result = prompt(questions)
+    cred_method = result.get("cred_method")
+
+    creds = {}
+    if cred_method and "file" in cred_method:
+        latest_file = find_latest_neo4j_creds_file()
+        file_to_parse = None
+        if latest_file:
+            confirm_questions = [
+                {
+                    "type": "confirm",
+                    "message": f"Found a credentials file: {latest_file}. Use this file?",
+                    "name": "use_latest",
+                    "default": True,
+                }
+            ]
+            if prompt(confirm_questions).get("use_latest"):
+                file_to_parse = latest_file
+
+        if not file_to_parse:
+            path_questions = [
+                {"type": "input", "message": "Please enter the path to your credentials file:", "name": "cred_file_path"}
+            ]
+            file_path_str = prompt(path_questions).get("cred_file_path", "")
+            file_path = Path(file_path_str.strip())
+            if file_path.exists() and file_path.is_file():
+                file_to_parse = file_path
+            else:
+                console.print("[red]❌ The specified file path does not exist or is not a file.[/red]")
+                return
+
+        if file_to_parse:
+            try:
+                with open(file_to_parse, "r") as f:
+                    for line in f:
+                        if "=" in line:
+                            key, value = line.strip().split("=", 1)
+                            if key == "NEO4J_URI":
+                                creds["uri"] = value
+                            elif key == "NEO4J_USERNAME":
+                                creds["username"] = value
+                            elif key == "NEO4J_PASSWORD":
+                                creds["password"] = value
+            except Exception as e:
+                console.print(f"[red]❌ Failed to parse credentials file: {e}[/red]")
+                return
+
+    elif cred_method: # Manual entry
+        console.print("Please enter your Neo4j connection details.")
+        
+        # Loop until valid credentials are provided
+        while True:
+            questions = [
+                {"type": "input", "message": "URI (e.g., 'neo4j://localhost:7687'):", "name": "uri", "default": "neo4j://localhost:7687"},
+                {"type": "input", "message": "Username:", "name": "username", "default": "neo4j"},
+                {"type": "password", "message": "Password:", "name": "password"},
+            ]
+            
+            manual_creds = prompt(questions)
+            if not manual_creds: 
+                return # User cancelled
+            
+            # Validate the user input
+            console.print("\n[cyan]🔍 Validating configuration...[/cyan]")
+            is_valid, validation_error = DatabaseManager.validate_config(
+                manual_creds.get("uri", ""),
+                manual_creds.get("username", ""),
+                manual_creds.get("password", "")
+            )
+            
+            if not is_valid:
+                console.print(validation_error)
+                console.print("\n[red]❌ Invalid configuration. Please try again.[/red]\n")
+                continue  # Ask for input again
+            
+            console.print("[green]✅ Configuration format is valid[/green]")
+            
+            # Test the connection
+            console.print("\n[cyan]🔗 Testing connection...[/cyan]")
+            is_connected, error_msg = DatabaseManager.test_connection(
+                manual_creds.get("uri", ""),
+                manual_creds.get("username", ""),
+                manual_creds.get("password", "")
+            )
+            
+            if not is_connected:
+                console.print(error_msg)
+                retry = prompt([{"type": "confirm", "message": "Connection failed. Try again with different credentials?", "name": "retry", "default": True}])
+                if not retry.get("retry"):
+                    return
+                continue  # Ask for input again
+            
+            console.print("[green]✅ Connection successful![/green]")
+            creds = manual_creds
+            break  # Exit loop with valid credentials
+
+
+    if creds.get("uri") and creds.get("password"):
+        _generate_mcp_json(creds)
+    else:
+        console.print("[red]❌ Incomplete credentials. Please try again.[/red]")
+
 
 def setup_hosted_db():
     """Guides user to configure a remote Neo4j instance."""
@@ -346,16 +607,55 @@ def setup_hosted_db():
                 console.print(f"[red]❌ Failed to parse credentials file: {e}[/red]")
                 return
 
-    elif cred_method:  # Manual entry
+    elif cred_method: # Manual entry
         console.print("Please enter your remote Neo4j connection details.")
-        questions = [
-            {"type": "input", "message": "URI (e.g., neo4j+s://xxxx.databases.neo4j.io):", "name": "uri"},
-            {"type": "input", "message": "Username:", "name": "username", "default": "neo4j"},
-            {"type": "password", "message": "Password:", "name": "password"},
-        ]
-        manual_creds = prompt(questions)
-        if not manual_creds: return  # User cancelled
-        creds = manual_creds
+        
+        # Loop until valid credentials are provided
+        while True:
+            questions = [
+                {"type": "input", "message": "URI (e.g., neo4j+s://xxxx.databases.neo4j.io):", "name": "uri"},
+                {"type": "input", "message": "Username:", "name": "username", "default": "neo4j"},
+                {"type": "password", "message": "Password:", "name": "password"},
+            ]
+            
+            manual_creds = prompt(questions)
+            if not manual_creds:
+                return # User cancelled
+            
+            # Validate the user input
+            console.print("\n[cyan]🔍 Validating configuration...[/cyan]")
+            is_valid, validation_error = DatabaseManager.validate_config(
+                manual_creds.get("uri", ""),
+                manual_creds.get("username", ""),
+                manual_creds.get("password", "")
+            )
+            
+            if not is_valid:
+                console.print(validation_error)
+                console.print("\n[red]❌ Invalid configuration. Please try again.[/red]\n")
+                continue  # Ask for input again
+            
+            console.print("[green]✅ Configuration format is valid[/green]")
+            
+            # Test the connection
+            console.print("\n[cyan]🔗 Testing connection...[/cyan]")
+            is_connected, error_msg = DatabaseManager.test_connection(
+                manual_creds.get("uri", ""),
+                manual_creds.get("username", ""),
+                manual_creds.get("password", "")
+            )
+            
+            if not is_connected:
+                console.print(error_msg)
+                retry = prompt([{"type": "confirm", "message": "Connection failed. Try again with different credentials?", "name": "retry", "default": True}])
+                if not retry.get("retry"):
+                    return
+                continue  # Ask for input again
+            
+            console.print("[green]✅ Connection successful![/green]")
+            creds = manual_creds
+            break  
+
 
     if creds.get("uri") and creds.get("password"):
         _generate_mcp_json(creds)
@@ -440,6 +740,21 @@ volumes:
 
     console.print("[green]✅ docker-compose.yml created with secure password.[/green]")
 
+    # Validate configuration format before attempting Docker operations
+    console.print("\n[cyan]🔍 Validating configuration...[/cyan]")
+    is_valid, validation_error = DatabaseManager.validate_config(
+        DEFAULT_NEO4J_URI, 
+        DEFAULT_NEO4J_USERNAME, 
+        password
+    )
+
+    if not is_valid:
+        console.print(validation_error)
+        console.print("\n[red]❌ Configuration validation failed. Please fix the issues and try again.[/red]")
+        return
+
+    console.print("[green]✅ Configuration format is valid[/green]")
+
     # Check if Docker is running
     docker_check = run_command(["docker", "--version"], console, check=False)
     if not docker_check:
@@ -484,29 +799,36 @@ volumes:
                     console.print("[red]❌ Neo4j container stopped unexpectedly. Check logs with: docker compose logs neo4j[/red]")
                     return
                 
-                # Try to connect
-                health_check = run_command([
-                    "docker", "exec", "neo4j-cgc", "cypher-shell", 
-                    "-u", "neo4j", "-p", password, 
-                    "RETURN 'Connection successful' as status"
-                ], console, check=False)
+                # updated test_connection method
+                console.print(f"[yellow]Testing connection... (attempt {attempt + 1}/{max_attempts})[/yellow]")
+                is_connected, error_msg = DatabaseManager.test_connection(DEFAULT_NEO4J_URI, DEFAULT_NEO4J_USERNAME, password)
                 
-                if health_check and health_check.returncode == 0:
+                if is_connected:
                     console.print("[bold green]✅ Neo4j is ready and accepting connections![/bold green]")
+                    connection_successful = True
                     break
-                    
-                if attempt < max_attempts - 1:
-                    console.print(f"[yellow]Still waiting... (attempt {attempt + 1}/{max_attempts})[/yellow]")
-            else:
-                console.print("[red]❌ Neo4j did not become ready within 2 minutes. Check logs with: docker compose logs neo4j[/red]")
+                
+                else:
+                    # Only show detailed error on last attempt
+                    if attempt == max_attempts - 1:
+                        console.print("\n[red]❌ Neo4j did not become ready within 2 minutes.[/red]")
+                        console.print(error_msg)
+                        console.print("\n[cyan]Troubleshooting:[/cyan]")
+                        console.print("  • Check logs: docker compose logs neo4j")
+                        console.print("  • Verify container is running: docker ps")
+                        console.print("  • Try restarting: docker compose restart")
+                        return
+            
+            if not connection_successful:
                 return
 
             # Generate MCP configuration
             creds = {
-                "uri": "neo4j://localhost:7687",  # Use neo4j:// protocol for Neo4j 5.x
-                "username": "neo4j",
+                "uri": DEFAULT_NEO4J_URI,
+                "username": DEFAULT_NEO4J_USERNAME,
                 "password": password
             }
+
             _generate_mcp_json(creds)
             
             console.print("\n[bold green]🎉 Setup complete![/bold green]")
