@@ -35,8 +35,8 @@ class TreeSitterParser:
             from .languages.javascript import JavascriptTreeSitterParser
             self.language_specific_parser = JavascriptTreeSitterParser(self)
         elif self.language_name == 'go':
-             from .languages.go import GoTreeSitterParser
-             self.language_specific_parser = GoTreeSitterParser(self)
+            from .languages.go import GoTreeSitterParser
+            self.language_specific_parser = GoTreeSitterParser(self)
         elif self.language_name == 'typescript':
             from .languages.typescript import TypescriptTreeSitterParser
             self.language_specific_parser = TypescriptTreeSitterParser(self)
@@ -193,8 +193,8 @@ class GraphBuilder:
             from .languages import typescript as ts_lang_module
             imports_map.update(ts_lang_module.pre_scan_typescript(files_by_lang['.ts'], self.parsers['.ts']))
         if '.tsx' in files_by_lang:
-            from .languages import typescript as ts_lang_module
-            imports_map.update(ts_lang_module.pre_scan_typescript(files_by_lang['.tsx'], self.parsers['.tsx']))
+            from .languages import typescriptjsx as tsx_lang_module
+            imports_map.update(tsx_lang_module.pre_scan_typescript(files_by_lang['.tsx'], self.parsers['.tsx']))
         if '.cpp' in files_by_lang:
             from .languages import cpp as cpp_lang_module
             imports_map.update(cpp_lang_module.pre_scan_cpp(files_by_lang['.cpp'], self.parsers['.cpp']))
@@ -331,13 +331,17 @@ class GraphBuilder:
                     """
                     session.run(query, file_path=file_path_str, name=item['name'], line_number=item['line_number'], props=item)
                     
+                    # Only create parameter nodes if INDEX_PARAMETERS is enabled
                     if label == 'Function':
-                        for arg_name in item.get('args', []):
-                            session.run("""
-                                MATCH (fn:Function {name: $func_name, file_path: $file_path, line_number: $line_number})
-                                MERGE (p:Parameter {name: $arg_name, file_path: $file_path, function_line_number: $line_number})
-                                MERGE (fn)-[:HAS_PARAMETER]->(p)
-                            """, func_name=item['name'], file_path=file_path_str, line_number=item['line_number'], arg_name=arg_name)
+                        index_parameters = get_config_value('INDEX_PARAMETERS')
+                        if index_parameters and index_parameters.lower() == 'true':
+                            for arg_name in item.get('args', []):
+                                session.run("""
+                                    MATCH (fn:Function {name: $func_name, file_path: $file_path, line_number: $line_number})
+                                    MERGE (p:Parameter {name: $arg_name, file_path: $file_path, function_line_number: $line_number})
+                                    MERGE (fn)-[:HAS_PARAMETER]->(p)
+                                """, func_name=item['name'], file_path=file_path_str, line_number=item['line_number'], arg_name=arg_name)
+
 
             # --- NEW: persist Ruby Modules ---
             for m in file_data.get('modules', []):
